==> jc-1.4.0.tar.gz: java/security/cert/X509CRLEntry.h <==
// public abstract class java.security.cert.X509CRLEntry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4aa1aa15aadaef9a java_security_cert_X509CRLEntry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_X509CRLEntry_H_
#define _JC_java_security_cert_X509CRLEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_java_util_Date$object;

// Typedefs
typedef struct _jc_java_security_cert_X509CRLEntry$sub_refs	_jc_java_security_cert_X509CRLEntry$sub_refs;
typedef struct _jc_java_security_cert_X509CRLEntry$sub_nonrefs	_jc_java_security_cert_X509CRLEntry$sub_nonrefs;
typedef struct _jc_java_security_cert_X509CRLEntry$refs	_jc_java_security_cert_X509CRLEntry$refs;
typedef struct _jc_java_security_cert_X509CRLEntry$nonrefs	_jc_java_security_cert_X509CRLEntry$nonrefs;
typedef struct _jc_java_security_cert_X509CRLEntry$object	_jc_java_security_cert_X509CRLEntry$object;

typedef const struct _jc_java_security_cert_X509CRLEntry$vmethods	_jc_java_security_cert_X509CRLEntry$vmethods;
typedef const struct _jc_java_security_cert_X509CRLEntry$vtable	_jc_java_security_cert_X509CRLEntry$vtable;
typedef const struct _jc_java_security_cert_X509CRLEntry$vtype	_jc_java_security_cert_X509CRLEntry$vtype;

// Constructors
extern void _jc_java_security_cert_X509CRLEntry$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *);

// Virtual methods
extern jboolean _jc_java_security_cert_X509CRLEntry$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *, struct _jc_java_lang_Object$object *);
extern _jc_byte_array *_jc_java_security_cert_X509CRLEntry$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *);
extern struct _jc_java_util_Date$object *_jc_java_security_cert_X509CRLEntry$method$getRevocationDate$f4bc39251cfa4263(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_cert_X509CRLEntry$method$getSerialNumber$7e3dedaf516a1567(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *);
extern jboolean _jc_java_security_cert_X509CRLEntry$method$hasExtensions$428c534df57e2d85(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *);
extern jint _jc_java_security_cert_X509CRLEntry$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_cert_X509CRLEntry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_X509CRLEntry$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_security_cert_X509CRLEntry$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_java_security_cert_X509CRLEntry$method_info$getRevocationDate$f4bc39251cfa4263;
extern _jc_method _jc_java_security_cert_X509CRLEntry$method_info$getSerialNumber$7e3dedaf516a1567;
extern _jc_method _jc_java_security_cert_X509CRLEntry$method_info$hasExtensions$428c534df57e2d85;
extern _jc_method _jc_java_security_cert_X509CRLEntry$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_security_cert_X509CRLEntry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_X509CRLEntry$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *, struct _jc_java_lang_Object$object *);
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *);
	struct _jc_java_util_Date$object	*(*getRevocationDate$f4bc39251cfa4263)(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *);
	struct _jc_java_math_BigInteger$object	*(*getSerialNumber$7e3dedaf516a1567)(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *);
	jboolean	(*hasExtensions$428c534df57e2d85)(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *);
};

// Vtable
struct _jc_java_security_cert_X509CRLEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_X509CRLEntry$vmethods	java_security_cert_X509CRLEntry;
};

// Vtype
struct _jc_java_security_cert_X509CRLEntry$vtype {
	_jc_type			type;
	_jc_java_security_cert_X509CRLEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_X509CRLEntry$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_X509CRLEntry$refs {
    _jc_java_security_cert_X509CRLEntry$sub_refs	java_security_cert_X509CRLEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_X509CRLEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_X509CRLEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_X509CRLEntry$sub_nonrefs	java_security_cert_X509CRLEntry;
};

// Object instance structure
struct _jc_java_security_cert_X509CRLEntry$object {
	_jc_java_security_cert_X509CRLEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_X509CRLEntry$vtype	*vtype;
	_jc_java_security_cert_X509CRLEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_X509CRLEntry$vtype _jc_java_security_cert_X509CRLEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_X509CRLEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_X509CRLEntry$class_object;

#endif	/* _JC_java_security_cert_X509CRLEntry_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/X509CRLEntry.h <==
// public abstract class java.security.cert.X509CRLEntry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4aa1aa15aadaef9a java_security_cert_X509CRLEntry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_X509CRLEntry_H_
#define _JC_java_security_cert_X509CRLEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_java_util_Date$object;

// Typedefs
typedef struct _jc_java_security_cert_X509CRLEntry$sub_refs	_jc_java_security_cert_X509CRLEntry$sub_refs;
typedef struct _jc_java_security_cert_X509CRLEntry$sub_nonrefs	_jc_java_security_cert_X509CRLEntry$sub_nonrefs;
typedef struct _jc_java_security_cert_X509CRLEntry$refs	_jc_java_security_cert_X509CRLEntry$refs;
typedef struct _jc_java_security_cert_X509CRLEntry$nonrefs	_jc_java_security_cert_X509CRLEntry$nonrefs;
typedef struct _jc_java_security_cert_X509CRLEntry$object	_jc_java_security_cert_X509CRLEntry$object;

typedef const struct _jc_java_security_cert_X509CRLEntry$vmethods	_jc_java_security_cert_X509CRLEntry$vmethods;
typedef const struct _jc_java_security_cert_X509CRLEntry$vtable	_jc_java_security_cert_X509CRLEntry$vtable;
typedef const struct _jc_java_security_cert_X509CRLEntry$vtype	_jc_java_security_cert_X509CRLEntry$vtype;

// Constructors
extern void _jc_java_security_cert_X509CRLEntry$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_security_cert_X509CRLEntry$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_java_security_cert_X509CRLEntry$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_Date$object *_jc_java_security_cert_X509CRLEntry$method$getRevocationDate$f4bc39251cfa4263(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_cert_X509CRLEntry$method$getSerialNumber$7e3dedaf516a1567(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_security_cert_X509CRLEntry$method$hasExtensions$428c534df57e2d85(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *) _JC_JCNI_ATTR;
extern jint _jc_java_security_cert_X509CRLEntry$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_cert_X509CRLEntry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_X509CRLEntry$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_security_cert_X509CRLEntry$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_java_security_cert_X509CRLEntry$method_info$getRevocationDate$f4bc39251cfa4263;
extern _jc_method _jc_java_security_cert_X509CRLEntry$method_info$getSerialNumber$7e3dedaf516a1567;
extern _jc_method _jc_java_security_cert_X509CRLEntry$method_info$hasExtensions$428c534df57e2d85;
extern _jc_method _jc_java_security_cert_X509CRLEntry$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_security_cert_X509CRLEntry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_X509CRLEntry$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_Date$object	*(*getRevocationDate$f4bc39251cfa4263)(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getSerialNumber$7e3dedaf516a1567)(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *) _JC_JCNI_ATTR;
	jboolean	(*hasExtensions$428c534df57e2d85)(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_X509CRLEntry$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_X509CRLEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_X509CRLEntry$vmethods	java_security_cert_X509CRLEntry;
};

// Vtype
struct _jc_java_security_cert_X509CRLEntry$vtype {
	_jc_type			type;
	_jc_java_security_cert_X509CRLEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_X509CRLEntry$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_X509CRLEntry$refs {
    _jc_java_security_cert_X509CRLEntry$sub_refs	java_security_cert_X509CRLEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_X509CRLEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_X509CRLEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_X509CRLEntry$sub_nonrefs	java_security_cert_X509CRLEntry;
};

// Object instance structure
struct _jc_java_security_cert_X509CRLEntry$object {
	_jc_java_security_cert_X509CRLEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_X509CRLEntry$vtype	*vtype;
	_jc_java_security_cert_X509CRLEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_X509CRLEntry$vtype _jc_java_security_cert_X509CRLEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_X509CRLEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_X509CRLEntry$class_object;

#endif	/* _JC_java_security_cert_X509CRLEntry_H_ */
